# Generated by Django 3.1.8 on 2021-04-23 11:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_sites", "0004_siteprofile_country_code"),
    ]

    operations = [
        migrations.AlterField(
            model_name="siteprofile",
            name="id",
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
    ]
